function vitePluginServerIslands({ settings }) {
  let viteServer = null;
  return {
    name: "astro:server-islands",
    enforce: "post",
    configureServer(_server) {
      viteServer = _server;
    },
    transform(code, id, options) {
      if (id.endsWith(".astro")) {
        const info = this.getModuleInfo(id);
        if (info?.meta) {
          const astro = info.meta.astro;
          if (astro?.serverComponents.length) {
            if (viteServer) {
              for (const comp of astro.serverComponents) {
                if (!settings.serverIslandNameMap.has(comp.resolvedPath)) {
                  let name = comp.localName;
                  let idx = 1;
                  while (true) {
                    if (!settings.serverIslandMap.has(name)) {
                      break;
                    }
                    name += idx++;
                  }
                  settings.serverIslandNameMap.set(comp.resolvedPath, name);
                  settings.serverIslandMap.set(name, () => {
                    return viteServer?.ssrLoadModule(comp.resolvedPath);
                  });
                }
              }
            }
          }
        }
      }
    }
  };
}
export {
  vitePluginServerIslands
};
